```
Usage: vcd vapp network delete-ip-range [OPTIONS] <vapp-name> <network-name>

Options:
  -i, --ip-range <ip>  ip range in StartAddress-EndAddress format  [required]
  -h, --help           Show this message and exit.

```
